@@ -10,7 +10,7 @@ App::Greple::tee - module to replace matched text by the external command result
 
 =head1 VERSION
 
-Version 1.00
+Version 1.01
 
 =head1 DESCRIPTION
 
@@ -72,6 +72,38 @@ passing them to the filter command.  Newline characters between wide
 width characters are deleted, and other newline characters are
 replaced with spaces.
 
+=item B<--squeeze>
+
+Combines two or more consecutive newline characters into one.
+
+=item B<-Mline> B<--offload> I<command>
+
+L<teip(1)>'s B<--offload> option is implemented in the different
+module B<-Mline>.
+
+    greple -Mtee cat -n -- -Mline --offload 'seq 10 20'
+
+You can also use the B<line> module to process only even-numbered
+lines as follows.
+
+    greple -Mtee cat -n -- -Mline 2::2
+
+=back
+
+=head1 LEGACIES
+
+The B<--blocks> option is no longer needed now that the B<--stretch>
+(B<-S>) option has been implemented in B<greple>.  You can simply
+perform the following.
+
+    greple -Mtee cat -n -- --all -SE foo
+
+It is not recommended to use B<--blocks> as it may be deprecated in
+the future.
+
+
+=over 7
+
 =item B<--blocks>
 
 Normally, the area matching the specified search pattern is sent to
@@ -95,10 +127,6 @@ the B<-o> option.
 Do not use the B<--blocks> with the B<--all> option, since the block
 will be the entire data.
 
-=item B<--squeeze>
-
-Combines two or more consecutive newline characters into one.
-
 =back
 
 =head1 WHY DO NOT USE TEIP
@@ -119,7 +147,7 @@ consisting of multiple lines.
 Next command will find text blocks inside L<perlpod(1)> style document
 included in Perl module file.
 
-    greple --inside '^=(?s:.*?)(^=cut|\z)' --re '^(\w.+\n)+' tee.pm
+    greple --inside '^=(?s:.*?)(^=cut|\z)' --re '^([\w\pP].+\n)+' tee.pm
 
 You can translate them by DeepL service by executing the above command
 convined with B<-Mtee> module which calls B<deepl> command like this:
@@ -226,7 +254,7 @@ it under the same terms as Perl itself.
 
 package App::Greple::tee;
 
-our $VERSION = "1.00";
+our $VERSION = "1.01";
 
 use v5.14;
 use warnings;
